const extendVue = (definition) => definition;

var __assign = Object.assign;
const baseURL = "https://cdn.sanity.io/images";
const projectId = "<%= options.projectId %>";
const dataset = "<%= options.dataset %>";
const isTemplated = projectId.includes("options");
const SanityImage = extendVue({
  functional: true,
  props: {
    assetId: {type: String, required: true},
    projectId: __assign({
      type: String
    }, isTemplated ? {required: true} : {
      default: projectId
    }),
    dataset: {
      type: String,
      default: isTemplated ? "production" : dataset
    },
    auto: {type: String},
    bg: {type: String},
    blur: {
      type: [Number, String],
      validator: (value) => Number(value) >= 0 && Number(value) <= 100
    },
    crop: {
      type: String,
      validator: (value) => [
        "top",
        "bottom",
        "left",
        "right",
        "center",
        "focalpoint",
        "entropy"
      ].includes(value)
    },
    dl: {type: String},
    dpr: {
      type: [Number, String],
      validator: (value) => [1, 2, 3].includes(Number(value))
    },
    fit: {
      type: String,
      validator: (value) => ["clip", "crop", "fill", "fillmax", "max", "scale", "min"].includes(value)
    },
    flip: {
      type: String,
      validator: (value) => ["h", "v", "hv"].includes(value)
    },
    fm: {
      type: String,
      validator: (value) => ["jpg", "pjpg", "png", "webp"].includes(value)
    },
    fpX: {
      type: [Number, String],
      validator: (value) => Number(value) <= 1 && Number(value) >= 0
    },
    fpY: {
      type: [Number, String],
      validator: (value) => Number(value) <= 1 && Number(value) >= 0
    },
    h: {type: [Number, String]},
    invert: {type: Boolean},
    maxH: {type: [Number, String]},
    maxW: {type: [Number, String]},
    minH: {type: [Number, String]},
    minW: {type: [Number, String]},
    or: {
      type: [Number, String],
      validator: (value) => [0, 90, 180, 270].includes(Number(value))
    },
    q: {
      type: [Number, String],
      validator: (value) => Number(value) >= 0 && Number(value) <= 100
    },
    rect: {type: String},
    sat: {type: [Number, String]},
    sharpen: {
      type: [Number, String],
      validator: (value) => Number(value) >= 0 && Number(value) <= 100
    },
    w: {type: [Number, String]}
  },
  render(h, {props, data}) {
    const keys = [
      "auto",
      "bg",
      "blur",
      "crop",
      "dl",
      "dpr",
      "fit",
      "flip",
      "fm",
      "fpX",
      "fpY",
      "h",
      "invert",
      "maxH",
      "maxW",
      "minH",
      "minW",
      "or",
      "rect",
      "sat",
      "sharpen",
      "w"
    ];
    const queryParams = keys.map((prop) => {
      const urlFormat = prop.replace(/[A-Z]./, (r) => "-" + r[1].toLowerCase());
      return props[prop] ? `${urlFormat}=${props[prop]}` : void 0;
    }).filter(Boolean).join("&");
    const parts = props.assetId.split("-").slice(1);
    const format = parts.pop();
    const src = `${baseURL}/${props.projectId}/${props.dataset}/${parts.join("-")}.${format}${queryParams ? "?" + queryParams : ""}`;
    return h("img", __assign(__assign({}, data), {
      attrs: __assign(__assign({}, data.attrs), {
        src
      })
    }));
  }
});

export { SanityImage };
